pub struct CreateThreadReq {
pub coordination_uuid: String,
pub author_name: String,
pub author_email: String,
pub author_role: String,
pub author_registrations: Vec<AuthorRegistration>,
pub care_location: String,
pub participants: Vec<MessageAuthor>,
pub initial_message_body: String,
pub initial_message_author: Option<MessageAuthor>,
pub author_signature: String,
}Fields
coordination_uuid: Stringcare_location: Stringparticipants: Vec<MessageAuthor>initial_message_body: StringTrait Implementations
Sourceimpl Clone for CreateThreadReq
impl Clone for CreateThreadReq
Sourcefn clone(&self) -> CreateThreadReq
fn clone(&self) -> CreateThreadReq
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for CreateThreadReq
impl Debug for CreateThreadReq
Sourceimpl Default for CreateThreadReq
impl Default for CreateThreadReq
Sourceimpl<'de> Deserialize<'de> for CreateThreadReq
impl<'de> Deserialize<'de> for CreateThreadReq
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl Message for CreateThreadReq
impl Message for CreateThreadReq
Sourcefn encoded_len(&self) -> usize
fn encoded_len(&self) -> usize
Returns the encoded length of the message without a length delimiter.
Sourcefn encode(&self, buf: &mut impl BufMut) -> Result<(), EncodeError>where
Self: Sized,
fn encode(&self, buf: &mut impl BufMut) -> Result<(), EncodeError>where
Self: Sized,
Encodes the message to a buffer. Read more
Sourcefn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message to a newly allocated buffer.
Sourcefn encode_length_delimited(
&self,
buf: &mut impl BufMut,
) -> Result<(), EncodeError>where
Self: Sized,
fn encode_length_delimited(
&self,
buf: &mut impl BufMut,
) -> Result<(), EncodeError>where
Self: Sized,
Encodes the message with a length-delimiter to a buffer. Read more
Sourcefn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message with a length-delimiter to a newly allocated buffer.
Sourcefn decode(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
fn decode(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
Decodes an instance of the message from a buffer. Read more
Sourcefn decode_length_delimited(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
fn decode_length_delimited(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
Decodes a length-delimited instance of the message from the buffer.
Sourcefn merge(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
fn merge(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
Decodes an instance of the message from a buffer, and merges it into
self. Read moreSourcefn merge_length_delimited(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
fn merge_length_delimited(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
Decodes a length-delimited instance of the message from buffer, and
merges it into
self.Sourceimpl PartialEq for CreateThreadReq
impl PartialEq for CreateThreadReq
Sourceimpl Serialize for CreateThreadReq
impl Serialize for CreateThreadReq
Sourceimpl<'__s> ToSchema<'__s> for CreateThreadReq
impl<'__s> ToSchema<'__s> for CreateThreadReq
impl StructuralPartialEq for CreateThreadReq